==> gail-0.3.tar.bz2: gail-0.3/gail/gailclist.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GAIL_CLIST_H__
#define __GAIL_CLIST_H__

#include <gtk/gtkaccessible.h>
#include <gail/gailcontainer.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GAIL_TYPE_CLIST                      (gail_clist_get_type ())
#define GAIL_CLIST(obj)                      (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAIL_TYPE_CLIST, GailCList))
#define GAIL_CLIST_CLASS(klass)              (G_TYPE_CHECK_CLASS_CAST ((klass), GAIL_TYPE_CLIST, GailCListClass))
#define GAIL_IS_CLIST(obj)                   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAIL_TYPE_CLIST))
#define GAIL_IS_CLIST_CLASS(klass)           (G_TYPE_CHECK_CLASS_TYPE ((klass), GAIL_TYPE_CLIST))
#define GAIL_CLIST_GET_CLASS(obj)            (G_TYPE_INSTANCE_GET_CLASS ((obj), GAIL_TYPE_CLIST, GailCListClass))

typedef struct _GailCList              GailCList;
typedef struct _GailCListClass         GailCListClass;

typedef struct _GailCListColumn        GailCListColumn;

struct _GailCList
{
  GailContainer parent;

  AtkObject*    caption;
  AtkObject*    summary;

  /* dynamically allocated array of column structures */
  GailCListColumn *columns;
  /* private */
  gint n_cols;
  GArray *row_data;
  GList *cell_data;
};

GType gail_clist_get_type (void);

struct _GailCListClass
{
  GailContainerClass parent_class;
};

GtkAccessible *gail_clist_new(GtkWidget *widget);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GAIL_CLIST_H__ */

==> gail-1.1.2.tar.bz2: gail-1.1.2/gail/gailclist.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GAIL_CLIST_H__
#define __GAIL_CLIST_H__

#include <gtk/gtkaccessible.h>
#include <gail/gailcontainer.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GAIL_TYPE_CLIST                      (gail_clist_get_type ())
#define GAIL_CLIST(obj)                      (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAIL_TYPE_CLIST, GailCList))
#define GAIL_CLIST_CLASS(klass)              (G_TYPE_CHECK_CLASS_CAST ((klass), GAIL_TYPE_CLIST, GailCListClass))
#define GAIL_IS_CLIST(obj)                   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAIL_TYPE_CLIST))
#define GAIL_IS_CLIST_CLASS(klass)           (G_TYPE_CHECK_CLASS_TYPE ((klass), GAIL_TYPE_CLIST))
#define GAIL_CLIST_GET_CLASS(obj)            (G_TYPE_INSTANCE_GET_CLASS ((obj), GAIL_TYPE_CLIST, GailCListClass))

typedef struct _GailCList              GailCList;
typedef struct _GailCListClass         GailCListClass;

typedef struct _GailCListColumn        GailCListColumn;

struct _GailCList
{
  GailContainer parent;

  AtkObject*    caption;
  AtkObject*    summary;

  /* dynamically allocated array of column structures */
  GailCListColumn *columns;
  /* private */
  gint n_cols;
  GArray *row_data;
  GList *cell_data;
};

GType gail_clist_get_type (void);

struct _GailCListClass
{
  GailContainerClass parent_class;
};

AtkObject* gail_clist_new (GtkWidget *widget);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GAIL_CLIST_H__ */
